package com.bipt.intelligentapplicationorchestrationservice.controller;

import com.bipt.intelligentapplicationorchestrationservice.pojo.*;
import com.bipt.intelligentapplicationorchestrationservice.service.DatasetService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
@Tag(name ="数据集相关接口")
@RestController
@RequestMapping("/dataset")
@Slf4j
public class DatasetController {
    @Autowired
    private DatasetService datasetService;

    /**
     * 新增数据集
     * @param datasetDTO
     * @return
     */
    @Operation(summary ="新增数据集")
    @PostMapping
    public OptResult save(@RequestBody DatasetDTO datasetDTO) {
        log.info("新增数据集:{}", datasetDTO);
        datasetService.save(datasetDTO);
        return OptResult.success();
    }

    /**
     * 分页查询
     * @param dataSetPageQueryDTO
     * @return
     */
    @Operation(summary ="分页查询")
    @GetMapping("/page")
    public OptResult<PageResult> page(DatasetPageQueryDTO dataSetPageQueryDTO) {
        log.info("数据集分页查询:{}", dataSetPageQueryDTO);
        PageResult pageResult = datasetService.pageQuery(dataSetPageQueryDTO);
        return OptResult.success(pageResult);
    }


    /**
     * 修改数据集
     * @param datasetDTO
     * @return
     */
    @Operation(summary ="修改数据集")
    @PutMapping
    public OptResult update(@RequestBody DatasetDTO datasetDTO){
        log.info("修改数据集",datasetDTO);
        datasetService.update(datasetDTO);
        return OptResult.success();
    }



    /**
     * 批量删除数据集
     * @param datasetIds 数据集ID列表
     * @return 操作结果
     */
    @Operation(summary ="删除数据集")
    @DeleteMapping
    public OptResult<String> deleteBatch(@RequestBody List<Long> datasetIds) {
        log.info("批量删除数据集，ID列表：{}", datasetIds);
        datasetService.deleteBatch(datasetIds);
        return OptResult.success("批量删除成功");
    }

}
