package com.bipt.intelligentapplicationorchestrationservice.service.Impl;

import com.bipt.intelligentapplicationorchestrationservice.constant.StatusConstant;
import com.bipt.intelligentapplicationorchestrationservice.enumeration.DatasetType;
import com.bipt.intelligentapplicationorchestrationservice.mapper.DatasetMapper;
import com.bipt.intelligentapplicationorchestrationservice.pojo.*;
import com.bipt.intelligentapplicationorchestrationservice.service.DatasetService;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.Collections;
import java.util.List;

import static com.bipt.intelligentapplicationorchestrationservice.enumeration.DatasetType.FROM_DATABASE;

@Service
@Slf4j
public class DatasetServiceImpl implements DatasetService {
    @Autowired
    private DatasetMapper datasetMapper;

    /**
     * 新增数据集
     * @param datasetDTO
     */
    @Override
    @Transactional
    public void save(DatasetDTO datasetDTO) {
        //判断数据集类型，如果是本地上传则保存，若用调用数据仓库进入下一步
        // 获取数据集类型
        DatasetType datasetType = DatasetType.fromCode(datasetDTO.getDatasetType());
        // 根据类型处理数据
        switch (datasetType) {
            case UPLOAD:
                //TODO 保存到分布式文件系统
                break;
            case FROM_DATABASE:
                String args = datasetDTO.getArgs();
                //TODO 根据筛选条件调用数据仓库中的数据

                //TODO 调用数据仓库保存到分布式文件系统
                break;
            default:
                throw new IllegalArgumentException("不支持的数据集类型: " + datasetType);
        }

        DatasetEntity datasetEntity = new DatasetEntity();
        BeanUtils.copyProperties(datasetDTO,datasetEntity);
        datasetEntity.setDatasetStatus(StatusConstant.ENABLE);
        datasetEntity.setCreateTime(LocalDateTime.now());
        datasetEntity.setUpdateTime(LocalDateTime.now());
        datasetMapper.insert(datasetEntity);

    }

    /**
     * 修改数据集
     *
     * @param datasetDTO
     */
    @Override
    @Transactional
    public void update(DatasetDTO datasetDTO) {
        /*DatasetEntity datasetEntity = new DatasetEntity();
        BeanUtils.copyProperties(datasetDTO,datasetEntity);*/
        DatasetType datasetType = DatasetType.fromCode(datasetDTO.getDatasetType());
        // 根据类型处理数据
        switch (datasetType) {
            case UPLOAD:
                //TODO 覆盖保存到分布式文件系统中
                break;
            case FROM_DATABASE:
                //TODO 覆盖数据文件

                break;
            default:
                throw new IllegalArgumentException("不支持的数据集类型: " + datasetType);
        }
        DatasetEntity datasetEntity = new DatasetEntity();
        BeanUtils.copyProperties(datasetDTO,datasetEntity);
        datasetEntity.setUpdateTime(LocalDateTime.now());
        datasetMapper.updata(datasetEntity);
    }

    /**
     * 分页查询
     * @param dataSetPageQueryDTO
     * @return
     */
    @Override
    public PageResult pageQuery(DatasetPageQueryDTO dataSetPageQueryDTO) {
        PageHelper.startPage(dataSetPageQueryDTO.getPage(), dataSetPageQueryDTO.getPageSize());
        Page<DatasetVO> page = datasetMapper.pageQuery(dataSetPageQueryDTO);
        return new PageResult(page.getTotal(), page.getResult());
    }

    /**
     * 批量删除
     * @param datasetIds
     */
    @Override
    @Transactional
    public void deleteBatch(List<Long> datasetIds) {

        //TODO 在分布式文件系统中删除
        datasetMapper.deleteBatch(datasetIds);
    }

}
